@@ -53,6 +53,11 @@ def parse_args(is_qtui):
                             default=False,
                             action='store_true',
                             help=tr("Directly start to create a new task"))
+    else:
+        parser.add_argument('-s', '--search',
+                            default=None,
+                            type=str,
+                            help=tr("Load search upon start"))
 
     parser.add_argument('filename',
                         type=str,
@@ -126,4 +131,3 @@ def run():
         success = -2
 
     return success
-
